@@ -3,7 +3,7 @@
 
 # This file is part of webscreenshot.
 #
-# Copyright (C) 2020, Thomas Debize <tdebize at mail.com>
+# Copyright (C) 2025, Thomas Debize <tdebize at mail.com>
 # All rights reserved.
 #
 # webscreenshot is free software: you can redistribute it and/or modify
@@ -49,7 +49,7 @@ else:
     izip = zip
 
 # Script version
-VERSION = '2.94'
+VERSION = '2.95'
 
 # Options definition
 parser = argparse.ArgumentParser()
@@ -471,6 +471,10 @@ def craft_cmd(url_and_options):
     # PhantomJS renderer
     if options.renderer == 'phantomjs':
         # If you ever want to add some voodoo options to the phantomjs command to be executed, that's here right below
+        
+        if not(is_windows()):
+            os.environ['OPENSSL_CONF'] = '/etc/ssl'
+        
         cmd_parameters = [ craft_bin_path(options),
                            '--ignore-ssl-errors=true',
                            '--ssl-protocol=any',
